@@ -25,8 +25,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <libgd/gd-main-toolbar.h>
-#include <libgd/gd-revealer.h>
+#include <libgd/gd.h>
 
 #include "logview-window.h"
 
@@ -42,13 +41,11 @@
 struct _LogviewWindowPrivate {
   PangoFontDescription *monospace_description;
 
+  GtkWidget *header_bar;
   GtkWidget *find_bar_revealer;
   GtkWidget *find_bar;
   GtkWidget *loglist;
-  GtkWidget *sidebar;
-  GtkWidget *hpaned;
   GtkWidget *text_view;
-  GtkWidget *toolbar;
 
   GtkWidget *message_area;
   GtkWidget *message_primary;
@@ -109,7 +106,6 @@ populate_tag_table (GtkTextTagTable *tag_table)
   gtk_text_tag_table_add (tag_table, tag); 
 }
 
-
 static void
 populate_style_tag_table (LogviewWindow *logview)
 {
@@ -163,43 +159,39 @@ _gtk_text_buffer_apply_tag_to_rectangle (GtkTextBuffer *buffer, int line_start,
 }
 
 static void
-logview_update_toolbar (LogviewWindow *logview, 
-                        LogviewLog *active,
-                        Day *selected_day)
+logview_update_header (LogviewWindow *logview,
+                       LogviewLog *active,
+                       Day *selected_day)
 {
   GString *string;
   GDateTime *log_time;
-  gchar *text;
+  gchar *title, *subtitle, *text;
   time_t timestamp;
 
+  title = subtitle = NULL;
+
   if (active == NULL) {
-    gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar),
-                                NULL, NULL);
-    return;
+    goto out;
   }
 
   if (gd_revealer_get_reveal_child (GD_REVEALER (logview->priv->find_bar_revealer))) {
-    text = g_strdup_printf (_("Search in \"%s\""),
-                            logview_log_get_display_name (active));
-    gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar),
-                                text, NULL);
-    g_free (text);
-    return;
+    title = g_strdup_printf (_("Search in \"%s\""),
+                             logview_log_get_display_name (active));
+    goto out;
   }
 
-  if (selected_day != NULL) {
-    text = logview_utils_format_date (selected_day->date);
-    gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar),
-                                logview_log_get_display_name (active), text);
-    g_free (text);
+  title = g_strdup (logview_log_get_display_name (active));
 
-    return;
+  if (selected_day != NULL) {
+    subtitle = logview_utils_format_date (selected_day->date);
+    goto out;
   }
 
   timestamp = logview_log_get_timestamp (active);
   log_time = g_date_time_new_from_unix_local (timestamp);
 
   text = logview_utils_format_date (log_time);
+  g_date_time_unref (log_time);
 
   /* translators: this is part of a label composed with
    * a date string, for example "updated today 23:54"
@@ -214,11 +206,14 @@ logview_update_toolbar (LogviewWindow *logview,
   g_string_append (string, text);
   g_free (text);
 
-  gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar),
-                              logview_log_get_display_name (active), string->str);
+  subtitle = g_string_free (string, FALSE);
 
-  g_string_free (string, TRUE);
-  g_date_time_unref (log_time);
+ out:
+  gd_header_bar_set_title (GD_HEADER_BAR (logview->priv->header_bar), title);
+  gd_header_bar_set_subtitle (GD_HEADER_BAR (logview->priv->header_bar), subtitle);
+
+  g_free (title);
+  g_free (subtitle);
 }
 
 #define DEFAULT_LOGVIEW_FONT "Monospace 10"
@@ -375,7 +370,10 @@ wrap:
 
   primary = g_strdup_printf (_("Search in \"%s\""),
                              logview_log_get_display_name (active_log));
-  gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar), primary, secondary);
+
+  gd_header_bar_set_title (GD_HEADER_BAR (logview->priv->header_bar), primary);
+  gd_header_bar_set_subtitle (GD_HEADER_BAR (logview->priv->header_bar), secondary);
+
 
   g_free (primary);
 }
@@ -641,7 +639,7 @@ loglist_day_selected_cb (LogviewLoglist *loglist,
   LogviewLog *active_log = logview_manager_get_active_log (logview_manager_get ());
 
   real_select_day (logview, day->first_line, day->last_line);
-  logview_update_toolbar (logview, active_log, day);
+  logview_update_header (logview, active_log, day);
 }
 
 static void
@@ -660,7 +658,7 @@ loglist_day_cleared_cb (LogviewLoglist *loglist,
   gtk_text_buffer_remove_tag_by_name (buffer, "invisible",
                                       &start, &end);
 
-  logview_update_toolbar (logview, active_log, NULL);
+  logview_update_header (logview, active_log, NULL);
 }
 
 static void
@@ -781,7 +779,7 @@ read_new_lines_cb (LogviewLog *log,
 
   paint_timestamps (buffer, old_line_count, new_days);
 
-  logview_update_toolbar (window, log, NULL);
+  logview_update_header (window, log, NULL);
   logview_loglist_update_lines (LOGVIEW_LOGLIST (window->priv->loglist), log);
 }
 
@@ -796,7 +794,7 @@ active_log_changed_cb (LogviewManager *manager,
   GtkTextBuffer *buffer;
 
   logview_clear_active_log_state (window, old_log);
-  logview_update_toolbar (window, log, NULL);
+  logview_update_header (window, log, NULL);
 
   lines = logview_log_get_cached_lines (log);
   buffer = gtk_text_buffer_new (window->priv->tag_table);
@@ -1142,7 +1140,7 @@ action_search_change_state (GSimpleAction *action,
     gtk_widget_grab_focus (logview->priv->find_bar);
   }
 
-  logview_update_toolbar (logview, active_log, NULL);
+  logview_update_header (logview, active_log, NULL);
 
   g_simple_action_set_state (action, state);
 }
@@ -1195,10 +1193,11 @@ logview_window_init_actions (LogviewWindow *window)
 static void
 logview_window_init (LogviewWindow *logview)
 {
-  GtkWidget *hpaned, *main_view, *vbox, *w;
+  GtkWidget *content, *w;
   gchar *monospace_font_name;
   LogviewWindowPrivate *priv;
   int width, height;
+  GError *err = NULL;
   GtkBuilder *builder;
   GMenuModel *menu;
 
@@ -1216,36 +1215,21 @@ logview_window_init (LogviewWindow *logview)
   logview_prefs_get_stored_window_size (priv->prefs, &width, &height);
   gtk_window_set_default_size (GTK_WINDOW (logview), width, height);
 
-  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_container_add (GTK_CONTAINER (logview), vbox);
-
-  /* create toolbar and menus */
-  priv->toolbar = gd_main_toolbar_new ();
-  gtk_style_context_add_class (gtk_widget_get_style_context (priv->toolbar),
-                               "menubar");
-  gtk_box_pack_start (GTK_BOX (vbox), priv->toolbar, FALSE, FALSE, 0);
-  gtk_widget_show_all (priv->toolbar);
-
-  w = gd_main_toolbar_add_toggle (GD_MAIN_TOOLBAR (priv->toolbar),
-                                  "edit-find-symbolic", NULL, FALSE);
-  gtk_actionable_set_action_name (GTK_ACTIONABLE (w), "win.search");
-
-  w = gd_main_toolbar_add_menu (GD_MAIN_TOOLBAR (priv->toolbar),
-                                "emblem-system-symbolic", NULL, FALSE);
-  gtk_widget_show (w);
+  gd_ensure_types ();
 
   builder = gtk_builder_new ();
-  gtk_builder_add_from_resource (builder, "/org/gnome/logview/logview-gear-menu.ui", NULL);
-  menu = G_MENU_MODEL (gtk_builder_get_object (builder, "gear-menu"));
-  gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (w), menu);
-  gtk_actionable_set_action_name (GTK_ACTIONABLE (w), "win.gear-menu");
 
+  if (!gtk_builder_add_from_resource (builder, "/org/gnome/logview/logview-window.ui", &err)) {
+    g_error ("failed to load ui: %s", err->message);
+  }
+
+  content = GTK_WIDGET (gtk_builder_get_object (builder, "window-content"));
+  gtk_container_add (GTK_CONTAINER (logview), content);
+
+  /* header bar and menus */
+  priv->header_bar = GTK_WIDGET (gtk_builder_get_object (builder, "headerbar"));
   priv->filters_placeholder = G_MENU_MODEL (gtk_builder_get_object (builder, "filters-placeholder"));
-  g_object_unref (builder);
-
-  priv->find_bar_revealer = gd_revealer_new ();
-  gtk_widget_show (priv->find_bar_revealer);
-  gtk_box_pack_start (GTK_BOX (vbox), priv->find_bar_revealer, FALSE, FALSE, 0);
+  priv->find_bar_revealer = GTK_WIDGET (gtk_builder_get_object (builder, "find-bar-revealer"));
 
   priv->find_bar = logview_findbar_new ();
   gtk_widget_show (priv->find_bar);
@@ -1260,29 +1244,12 @@ logview_window_init (LogviewWindow *logview)
   g_signal_connect (priv->find_bar, "close",
                     G_CALLBACK (findbar_close_cb), logview);
   
-  /* panes */
-  hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
-  gtk_box_pack_start (GTK_BOX (vbox), hpaned, TRUE, TRUE, 0);
-  priv->hpaned = hpaned;
-  gtk_widget_show (hpaned);
-
-  /* first pane : sidebar (list of logs) */
-  priv->sidebar = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_widget_show (priv->sidebar);
-
-  /* first pane: log list */
-  w = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w),
-                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (w),
-                                       GTK_SHADOW_ETCHED_IN);
+  /* sidebar (list of logs) */
+  w = GTK_WIDGET (gtk_builder_get_object (builder, "sidebar-scrolledwindow"));
 
   priv->loglist = logview_loglist_new ();
-  gtk_container_add (GTK_CONTAINER (w), priv->loglist);
-  gtk_box_pack_start (GTK_BOX (priv->sidebar), w, TRUE, TRUE, 0);
-  gtk_paned_pack1 (GTK_PANED (hpaned), priv->sidebar, FALSE, FALSE);
-  gtk_widget_show (w);
   gtk_widget_show (priv->loglist);
+  gtk_container_add (GTK_CONTAINER (w), priv->loglist);
 
   g_signal_connect (priv->loglist, "day_selected",
                     G_CALLBACK (loglist_day_selected_cb), logview);
@@ -1290,34 +1257,18 @@ logview_window_init (LogviewWindow *logview)
                     G_CALLBACK (loglist_day_cleared_cb), logview);
 
   /* second pane: log */
-  main_view = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_paned_pack2 (GTK_PANED (hpaned), main_view, TRUE, TRUE);
-
-  /* second pane: error message area */
-  priv->message_area = gtk_info_bar_new ();
+  priv->message_area = GTK_WIDGET (gtk_builder_get_object (builder, "error-infobar"));
   message_area_create_error_box (logview, priv->message_area);
   gtk_info_bar_add_button (GTK_INFO_BAR (priv->message_area),
                            GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-  gtk_box_pack_start (GTK_BOX (main_view), priv->message_area, FALSE, FALSE, 0);
 
-  /* second pane: text view */
-  w = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w),
-                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (w), GTK_SHADOW_IN);
-  gtk_box_pack_start (GTK_BOX (main_view), w, TRUE, TRUE, 0);
-  gtk_widget_show (w);
+  priv->text_view = GTK_WIDGET (gtk_builder_get_object (builder, "log-textview"));
 
   priv->tag_table = gtk_text_tag_table_new ();
   populate_tag_table (priv->tag_table);
 
-  priv->text_view = gtk_text_view_new ();
-  g_object_set (priv->text_view, "editable", FALSE, NULL);
   populate_style_tag_table (logview);
 
-  gtk_container_add (GTK_CONTAINER (w), priv->text_view);
-  gtk_widget_show (priv->text_view);
-
   /* use the desktop monospace font */
   monospace_font_name = logview_prefs_get_monospace_font_name (priv->prefs);
   logview_set_font (logview, monospace_font_name);
@@ -1341,9 +1292,8 @@ logview_window_init (LogviewWindow *logview)
                     G_CALLBACK (active_log_changed_cb), logview);
 
   update_filter_menu (logview);
-  
-  gtk_widget_show (vbox);
-  gtk_widget_show (main_view);
+
+  g_object_unref (builder);
 }
 
 static void
